@@ -42,7 +42,7 @@ const (
 	Version1_24 = "1.24"
 
 	// DefaultVersion (default)
-	DefaultVersion = Version1_23
+	DefaultVersion = Version1_24
 
 	LatestVersion = Version1_24
 
@@ -860,6 +860,8 @@ type Outpost struct {
 	ControlPlaneOutpostARN string `json:"controlPlaneOutpostARN"`
 	// ControlPlaneInstanceType specifies the instance type to use for creating the control plane instances.
 	ControlPlaneInstanceType string `json:"controlPlaneInstanceType"`
+	// ControlPlanePlacement specifies the placement configuration for control plane instances on Outposts.
+	ControlPlanePlacement *Placement `json:"controlPlanePlacement,omitempty"`
 }
 
 // GetInstanceType returns the control plane instance type.
@@ -872,6 +874,11 @@ func (o *Outpost) SetInstanceType(instanceType string) {
 	o.ControlPlaneInstanceType = instanceType
 }
 
+// HasPlacementGroup reports whether this Outpost has a placement group.
+func (o *Outpost) HasPlacementGroup() bool {
+	return o.ControlPlanePlacement != nil
+}
+
 // OutpostInfo describes the Outpost info.
 type OutpostInfo interface {
 	// IsControlPlaneOnOutposts returns true if the control plane is on Outposts.
