@@ -1,6 +1,7 @@
 package create
 
 import (
+	"errors"
 	"fmt"
 	"time"
 
@@ -14,9 +15,13 @@ import (
 	"github.com/aws/aws-sdk-go-v2/service/outposts"
 	outpoststypes "github.com/aws/aws-sdk-go-v2/service/outposts/types"
 	"github.com/aws/aws-sdk-go/aws/credentials"
+	"github.com/aws/smithy-go"
+
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+
 	"github.com/stretchr/testify/mock"
+
 	kubefake "k8s.io/client-go/kubernetes/fake"
 	restclient "k8s.io/client-go/rest"
 
@@ -31,6 +36,8 @@ import (
 	"github.com/weaveworks/eksctl/pkg/testutils/mockprovider"
 )
 
+const outpostARN = "arn:aws:outposts:us-west-2:1234:outpost/op-1234"
+
 var _ = Describe("create cluster", func() {
 	Describe("un-managed node group", func() {
 		It("understands ssh access arguments correctly", func() {
@@ -226,7 +233,7 @@ var _ = Describe("create cluster", func() {
 						Version: "",
 					},
 					Outpost: &api.Outpost{
-						ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+						ControlPlaneOutpostARN: outpostARN,
 					},
 				}
 
@@ -247,7 +254,7 @@ var _ = Describe("create cluster", func() {
 						Version: "1.20",
 					},
 					Outpost: &api.Outpost{
-						ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+						ControlPlaneOutpostARN: outpostARN,
 					},
 				}
 
@@ -379,7 +386,7 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN: outpostARN,
 				}
 			},
 			mockOutposts: true,
@@ -389,20 +396,20 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN:   "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN:   outpostARN,
 					ControlPlaneInstanceType: "t2.medium",
 				}
 			},
 			mockOutposts: true,
 
-			expectedErr: `instance type "t2.medium" does not exist in Outpost "arn:aws:outposts:us-west-2:1234:outpost/op-1234"`,
+			expectedErr: fmt.Sprintf(`instance type "t2.medium" does not exist in Outpost %q`, outpostARN),
 		}),
 
 		Entry("[Outposts] available instance type specified for the control plane", createClusterEntry{
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN:   "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN:   outpostARN,
 					ControlPlaneInstanceType: "m5.xlarge",
 				}
 			},
@@ -413,7 +420,7 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN: outpostARN,
 				}
 				c.NodeGroups = []*api.NodeGroup{
 					api.NewNodeGroup(),
@@ -428,7 +435,7 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				ng := api.NewNodeGroup()
-				ng.OutpostARN = "arn:aws:outposts:us-west-2:1234:outpost/op-1234"
+				ng.OutpostARN = outpostARN
 				c.NodeGroups = []*api.NodeGroup{ng}
 			},
 			mockOutposts: true,
@@ -441,7 +448,7 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN: outpostARN,
 				}
 				c.NodeGroups = []*api.NodeGroup{
 					api.NewNodeGroup(),
@@ -457,16 +464,62 @@ var _ = Describe("create cluster", func() {
 			updateClusterConfig: func(c *api.ClusterConfig) {
 				c.Metadata.Version = api.Version1_21
 				c.Outpost = &api.Outpost{
-					ControlPlaneOutpostARN: "arn:aws:outposts:us-west-2:1234:outpost/op-1234",
+					ControlPlaneOutpostARN: outpostARN,
 				}
 			},
 			updateMocks: func(provider *mockprovider.MockProvider) {
 				provider.MockOutposts().On("GetOutpost", mock.Anything, &outposts.GetOutpostInput{
-					OutpostId: aws.String("arn:aws:outposts:us-west-2:1234:outpost/op-1234"),
+					OutpostId: aws.String(outpostARN),
 				}).Return(nil, &outpoststypes.NotFoundException{Message: aws.String("not found")})
 			},
 			expectedErr: "error getting Outpost details: NotFoundException: not found",
 		}),
+
+		Entry("[Outposts] specified Outpost placement group does not exist", createClusterEntry{
+			updateClusterConfig: func(c *api.ClusterConfig) {
+				c.Metadata.Version = api.Version1_21
+				c.Outpost = &api.Outpost{
+					ControlPlaneOutpostARN: outpostARN,
+					ControlPlanePlacement: &api.Placement{
+						GroupName: "test",
+					},
+				}
+			},
+			updateMocks: func(provider *mockprovider.MockProvider) {
+				provider.MockEC2().On("DescribePlacementGroups", mock.Anything, &ec2.DescribePlacementGroupsInput{
+					GroupNames: []string{"test"},
+				}).Return(nil, &smithy.OperationError{
+					OperationName: "DescribePlacementGroups",
+					Err:           errors.New("api error InvalidPlacementGroup.Unknown: The Placement Group 'test' is unknown"),
+				})
+			},
+			mockOutposts: true,
+			expectedErr:  `placement group "test" does not exist`,
+		}),
+
+		Entry("[Outposts] valid Outpost placement group specified", createClusterEntry{
+			updateClusterConfig: func(c *api.ClusterConfig) {
+				c.Metadata.Version = api.Version1_21
+				c.Outpost = &api.Outpost{
+					ControlPlaneOutpostARN: outpostARN,
+					ControlPlanePlacement: &api.Placement{
+						GroupName: "test",
+					},
+				}
+			},
+			updateMocks: func(provider *mockprovider.MockProvider) {
+				provider.MockEC2().On("DescribePlacementGroups", mock.Anything, &ec2.DescribePlacementGroupsInput{
+					GroupNames: []string{"test"},
+				}).Return(&ec2.DescribePlacementGroupsOutput{
+					PlacementGroups: []ec2types.PlacementGroup{
+						{
+							GroupName: aws.String("test"),
+						},
+					},
+				}, nil)
+			},
+			mockOutposts: true,
+		}),
 	)
 })
 
@@ -578,12 +631,11 @@ func defaultProviderMocks(p *mockprovider.MockProvider, output []cftypes.Output,
 		},
 	}, nil)
 
-	const outpostID = "arn:aws:outposts:us-west-2:1234:outpost/op-1234"
 	var outpostConfig *ekstypes.OutpostConfigResponse
 	if controlPlaneOnOutposts {
-		mockOutposts(p, outpostID)
+		mockOutposts(p, outpostARN)
 		outpostConfig = &ekstypes.OutpostConfigResponse{
-			OutpostArns:              []string{outpostID},
+			OutpostArns:              []string{outpostARN},
 			ControlPlaneInstanceType: aws.String("m5.xlarge"),
 		}
 	}
